pub enum SpanInfoKey {
AttributeName(Node, NameId),
AttributeValue(Node, NameId),
ElementStart(Node),
ElementEnd(Node),
Text(Node),
Comment(Node),
PiTarget(Node),
PiContent(Node),
}Expand description
A key to use to look up span information using
SpanInfo::get
Variants
AttributeName(Node, NameId)
The name part of an attribute.
In foo:name="value", the foo:name part
AttributeValue(Node, NameId)
The value part of an attribute.
In foo:name="value", the value part
ElementStart(Node)
The name part of a start element tag.
In <foo:name ..>, the foo:name part
ElementEnd(Node)
The closing part of the end element tag (or a self-closing element).
In </foo:name>, the </foo:name> part, or if it is an empty element
<foo:name/>, the /> part
Text(Node)
Text node.
In <foo>text</foo>, the text part
Comment(Node)
Comment node.
In <!--comment-->, the comment part
PiTarget(Node)
The target part of a processing instruction.
In <?target content?>, the target part
PiContent(Node)
The content part of a processing instruction (if defined).
In <?target content?>, the content part